@@ -1,3 +1,24 @@
+#  The MIT License (MIT)
+#  Copyright (c) 2021-present foxwhite25
+#
+#  Permission is hereby granted, free of charge, to any person obtaining a
+#  copy of this software and associated documentation files (the "Software"),
+#  to deal in the Software without restriction, including without limitation
+#  the rights to use, copy, modify, merge, publish, distribute, sublicense,
+#  and/or sell copies of the Software, and to permit persons to whom the
+#  Software is furnished to do so, subject to the following conditions:
+#
+#  The above copyright notice and this permission notice shall be included in
+#  all copies or substantial portions of the Software.
+#
+#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+#  DEALINGS IN THE SOFTWARE.
+
 from __future__ import annotations
 
 import asyncio
@@ -60,7 +81,7 @@ async def json_or_text(response: aiohttp.ClientResponse) -> Union[Dict[str, Any]
     try:
         if response.headers['content-type'] == 'application/json':
             return utils._from_json(text)
-    except KeyError:
+    except Exception:
         # Thanks Cloudflare
         pass
 
@@ -542,23 +563,28 @@ class HTTPClient:
     ) -> Response[None]:
         params: Dict[str, Any] = {}
         if isinstance(duration, datetime.datetime):
-            params['mute_end_timstamp'] = str(duration.timestamp())
+            params['mute_end_timestamp'] = str(int(duration.timestamp() * 1000))
         else:
             params['mute_seconds'] = str(duration)
 
         r = Route('PATCH', '/guilds/{guild_id}/members/{user_id}/mute', guild_id=guild_id, user_id=user_id)
-        return self.request(r, params=params, reason=reason)
+        return self.request(r, json=params, reason=reason)
 
     def mute_guild(
-            self, guild_id: int, duration: Union[datetime.datetime, int], reason:str
+            self, guild_id: int, duration: Union[datetime.datetime, int], reason: str
     ) -> Response[None]:
         params: Dict[str, Any] = {}
         if isinstance(duration, datetime.datetime):
-            params['mute_end_timstamp'] = str(duration.timestamp())
+            params['mute_end_timestamp'] = str(int(duration.timestamp() * 1000))
         else:
             params['mute_seconds'] = str(duration)
-        print(params)
 
         r = Route('PATCH', '/guilds/{guild_id}/mute', guild_id=guild_id)
-        return self.request(r, params=params, reason=reason)
+        return self.request(r, json=params, reason=reason)
 
+    def delete_message(
+            self, channel_id: int, message_id: str, *, reason: Optional[str] = None
+    ) -> Response[None]:
+        r = Route('DELETE', '/channels/{channel_id}/messages/{message_id}', channel_id=channel_id,
+                  message_id=message_id)
+        return self.request(r, reason=reason)
