@@ -296,7 +296,7 @@ class ConnectionState:
         if not emoji_id:
             return data['name']
 
-        return PartialEmoji.with_state(self, animated=data.get('animated', False), id=emoji_id, name=data['name'])
+        return PartialEmoji.with_state(self, id=emoji_id, custom=False)
 
     async def chunker(
             self, guild_id: int, query: str = '', limit: int = 0, presences: bool = False, *,
@@ -399,7 +399,7 @@ class ConnectionState:
 
     def parse_at_message_create(self, data) -> None:
         channel, _ = self._get_guild_channel(data)
-        data['content'] = data['content'].replace(self.user.mention, '').removeprefix(' ').strip()
+        data['content'] = data['content'].replace(self.user.mention, '').strip()
         # channel would be the correct type here
         message = Message(channel=channel, data=data, state=self)  # type: ignore
         self.dispatch('message', message)
